TriplesFactory
==============

.. currentmodule:: pykeen.triples

.. autoclass:: TriplesFactory
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TriplesFactory.entity_id_to_label
      ~TriplesFactory.entity_to_id
      ~TriplesFactory.file_name_entity_to_id
      ~TriplesFactory.file_name_relation_to_id
      ~TriplesFactory.relation_id_to_label
      ~TriplesFactory.relation_to_id
      ~TriplesFactory.triples

   .. rubric:: Methods Summary

   .. autosummary::

      ~TriplesFactory.clone_and_exchange_triples
      ~TriplesFactory.entities_to_ids
      ~TriplesFactory.entity_word_cloud
      ~TriplesFactory.from_labeled_triples
      ~TriplesFactory.from_path
      ~TriplesFactory.get_inverse_relation_id
      ~TriplesFactory.get_mask_for_relations
      ~TriplesFactory.label_triples
      ~TriplesFactory.map_triples
      ~TriplesFactory.new_with_restriction
      ~TriplesFactory.relation_word_cloud
      ~TriplesFactory.relations_to_ids
      ~TriplesFactory.tensor_to_df
      ~TriplesFactory.to_core_triples_factory
      ~TriplesFactory.to_path_binary

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_id_to_label
   .. autoattribute:: entity_to_id
   .. autoattribute:: file_name_entity_to_id
   .. autoattribute:: file_name_relation_to_id
   .. autoattribute:: relation_id_to_label
   .. autoattribute:: relation_to_id
   .. autoattribute:: triples

   .. rubric:: Methods Documentation

   .. automethod:: clone_and_exchange_triples
   .. automethod:: entities_to_ids
   .. automethod:: entity_word_cloud
   .. automethod:: from_labeled_triples
   .. automethod:: from_path
   .. automethod:: get_inverse_relation_id
   .. automethod:: get_mask_for_relations
   .. automethod:: label_triples
   .. automethod:: map_triples
   .. automethod:: new_with_restriction
   .. automethod:: relation_word_cloud
   .. automethod:: relations_to_ids
   .. automethod:: tensor_to_df
   .. automethod:: to_core_triples_factory
   .. automethod:: to_path_binary
